@@ -15,13 +15,12 @@ from inforion.ionapi.model import *
 from inforion.merging.merging import merge_files
 from inforion.transformation.transform import parallelize_tranformation
 
-# from logger import get_logger
+from inforion.logger.logger import get_logger
 
-# from ionbasic import load_config
+logger = get_logger("inforion-init", True)
 
 # Codee Junaid
 
-
 def main_load(
     url=None,
     ionfile=None,
@@ -33,7 +32,7 @@ def main_load(
     end=None,
     on_progress=None,
 ):
-    
+
     if validators.url(url) != True:
         logging.info("Error: URL is not valid")
         return "Error: URL is not valid"
@@ -122,6 +121,7 @@ def main_transformation(
             return "There is an error while transforming the records. " + ex.message
         else:
             return "There is an unknown error while transforming the records."
+        sys.exit(1)
 
 def main_transformation_from_db(
     mappingfile=None, mainsheet=None, db_config=None, table_name=None, outputfile=None
@@ -144,23 +144,33 @@ def main_transformation_from_db(
         return "Error: Table name is missing."
 
     db_cred = get_db_credentials(db_config)
-    conn_string = 'DRIVER={'+db_cred['driver']+'};'+'SERVER={0};DATABASE={1};UID={2};PWD={3}'.format(db_cred['servername'],db_cred['database'],db_cred['username'],db_cred['password'])
+    conn_string = (
+        "DRIVER={"
+        + db_cred["driver"]
+        + "};"
+        + "SERVER={0};DATABASE={1};UID={2};PWD={3}".format(
+            db_cred["servername"],
+            db_cred["database"],
+            db_cred["username"],
+            db_cred["password"],
+        )
+    )
     sql_conn = pyodbc.connect(conn_string)
-    
+
     query = "SELECT * FROM {0}".format(table_name)
     data = pd.read_sql(query, sql_conn)
 
     try:
-        return parallelize_tranformation(
-            mappingfile, mainsheet, data, outputfile
-        )
+        return parallelize_tranformation(mappingfile, mainsheet, data, outputfile)
     except Exception as ex:
-        if ex.message:
+        logger.exception(ex)
+        if hasattr(ex, "message"):
             return "There is an error while transforming the records. " + ex.message
         else:
-            return "There is an unknown error while transforming the records."
+            return "There is an unknown error while transforming the records. "
         sys.exit(1)
 
+
 def main_merge(
     mergesheet1=None,
     mergesheet2=None,
